// president/pages/part_call_in/part_call_in.js
import { routers, viewImage, sharePage, isFn, getGlobalVal } from '../../../utils/util.js'
import { CallInList, DeleteBooks  } from '../../../utils/api.js'
const { navigateTo, redirectTo, navigateBack } = routers()
const { globalData } = getApp()
const { baseImgUrl, thumbnail } = globalData
Page({

  /**
   * 页面的初始数据
   */
  data: {
    baseImgUrl,
    thumbnail,
    isLoaded: 0,
    title: '',
    pageNo: 1,
    pageSize: 10,
    isAll: false,
    navIndex: 0,
    list: [],
    isAllCheck: 0,
    isManage: 0,
    totalNum: 0,
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    options.vipId = getGlobalVal('vipId', `vipId_${getGlobalVal('userId')}`)
    options.libId = getGlobalVal('list').length > 0 ? getGlobalVal('list')[0].libId : ''
    // wx.setNavigationBarTitle({
    //   title: `${options.theme}`,
    // })
    this.setData({ options, isAllCheck: options.status == 1 })
    
  },

  /**
   * 生命周期函数--监听页面初次渲染完成
   */
  onReady: function () {
    const obj = { navigateTo, redirectTo, navigateBack, viewImage }
    for (const i in obj) {
      this[i] = obj[i]
    }
  },

  /**
   * 生命周期函数--监听页面显示
   */
  onShow: function () {
    this.getData(() => {
      this.setData({ isLoaded: true })
    })
  },

  /**
   * 生命周期函数--监听页面隐藏
   */
  onHide: function () {

  },

  /**
   * 生命周期函数--监听页面卸载
   */
  onUnload: function () {

  },

  /**
   * 页面相关事件处理函数--监听用户下拉动作
   */
  onPullDownRefresh: function () {
    this.setData({ pageNo: 1 })
    this.getData(() => {
      wx.stopPullDownRefresh()
    })
  },

  /**
   * 页面上拉触底事件的处理函数
   */
  onReachBottom: function () {
    const { isAll } = this.data
    if (isAll) return
    this.getData()
  },

  /**
   * 用户点击右上角分享
   */
  onShareAppMessage: function () {
    if (isFn(sharePage)) return sharePage()
  },

  /**
   * 在馆书籍
   */
  getData: function (cb) {
    const continuousFn = { fn: this.getData, param: { ...arguments } }
    const { pageNo, pageSize, list, options, isAllCheck } = this.data
    const { libId } = options
    CallInList({ data: { libId, pageNo, pageSize }, continuousFn }).then(res => {
      const newList = ((list, isCheck) => {
        for (let i in list) {
          list[i].isCheck = isCheck
        }
        return list
      })(res.data.list, isAllCheck)
      let tempList = []
      if (pageNo == 1) {
        tempList = newList
      } else {
        tempList = [...list, ...newList]
      }
      const temp = {}
      temp[`list`] = tempList
      temp['pageNo'] = newList.length == pageSize ? ~~pageNo + 1 : pageNo
      temp['isAll'] = newList.length < pageSize
      this.setData(temp)
      this.caclulateBook()
      if (isFn(cb)) cb()
    }).catch(res => {
      if (isFn(cb)) cb()
    })
  },

  /**
  * 选择全部图书
  */
  checkAllCtl: function () {
    const { list, isAllCheck } = this.data
    const temp = {}
    for (let i in list) {
      temp[`list[${i}].isCheck`] = isAllCheck != 1 ? 1 : 0
    }
    this.setData(temp)
    this.caclulateBook()
  },

  /**
   * 选择图书
   */
  toggleSelectLiCtl: function (e) {
    const { index } = e.currentTarget.dataset
    const { list } = this.data
    const { isCheck = 0 } = list[index]
    const temp = {}
    temp[`list[${index}].isCheck`] = isCheck != 1 ? 1 : 0
    this.setData(temp)
    this.caclulateBook()
  },

  /**
   * 计算书籍
   */
  caclulateBook: function () {
    const { list } = this.data
    let num = 0
    const bookList = []
    for (const v of list) {
      const { id, isCheck } = v
      if (isCheck == 1) {
        num++
        bookList.push({
          id
        })
      }
    }
    this.setData({ totalNum: num, bookList, isAllCheck: bookList.length == list.length })
  },

  /**
   * 批量删除
   */
  getCallin: function () {
    const continuousFn = { fn: this.getCallin, param: { ...arguments } }
    const { list,options } = this.data
    const { libId} = options
    const ids = []
    console.log(list)
    for (let i in list) {
      if (list[i].isCheck==1){
        ids.push(list[i].book_info_id);
      }
    }
    DeleteBooks({ data: { ids, libId }, continuousFn }).then(res => {
      wx.showToast({
        title: `已删除成功`
      })
      setTimeout(() => {
        navigateBack()
      }, 1000)
    })
  },

  /**
   * 取消调入
   */
  cancelCallin: function () {
    this.setData({ isAllCheck: 1 })
    this.checkAllCtl()
  },

  /**
   * 输入搜索值
   */
  inputSearchCtl: function (e) {
    const { value } = e.detail
    const { title } = this.data
    if (title == value) return
    const temp = {}
    temp[`title`] = value
    this.setData(temp)
  },

  /**
   * 清除搜索值
   */
  clearSearchCtl: function () {
    const temp = {}
    temp[`title`] = ''
    this.setData(temp)
  },

  /**
   * 提交搜索值
   */
  submitSearchCtl: function () {
    const temp = {}
    temp[`pageNo`] = 1
    this.setData(temp)
    this.getData()
  },
})